@@ -46,6 +46,12 @@ def _get_figure_and_axis():
 
 
 def _set_ticks(xmin, xmax, ymin, ymax):
+
+    if xmin % 2 == 0:
+        xmin = xmin + 1
+    if xmax % 2 == 0:
+        xmax = xmax - 1
+
     n_step = 1
     xticks = list(np.arange(xmin + 1, xmax, n_step))
     while len(xticks) > 10:
@@ -56,6 +62,11 @@ def _set_ticks(xmin, xmax, ymin, ymax):
         xticks.remove(0)
     plt.xticks(xticks, fontsize=16)
 
+    if ymin % 2 == 0:
+        ymin = ymin + 1
+    if ymax % 2 == 0:
+        ymax = ymax - 1
+
     n_step = 1
     yticks = list(np.arange(ymin + 1, ymax, n_step))
     while len(yticks) > 10:
